{% extends "accounts/account_form.html" %}
{% load i18n %}

{% block account_form_actions %}
{{ block.super }}
<a class="btn btn-default btn-lg pull-left" href="{% url "shop_order_history" %}">{% trans "View past orders" %}</a>
{% endblock %}
