{% extends "admin/change_list.html" %}
{% load shop_tags %}

{% block object-tools-items %}
    {% if content_models.count > 1 %}
        <li>
            {% include "admin/includes/content_typed_change_list.html" %}
        </li>
    {% else %}
          {{ block.super }}
    {% endif %}
{% endblock %}
