/*================================
    Categories and products
==================================*/
.shop-category-list h4 {
    margin: 0;
}
.product-sorting {
    margin: 20px 0 25px;
}
.product-sorting select {
    display: inline-block;
    margin-left: 10px;
    width: 250px;
}
.shop-category-list .thumbnail,
.product-thumb > a {
    text-decoration: none;
}
.price:only-child,
.coming-soon {
    margin: 20px 0 8px;
    display: block;
}
.product-thumb h6 {
    color: #777;
    font-weight: bold;
    height: 50px;
    margin: 10px 0 5px 0;
    border-bottom: 1px dashed #ddd;
}
.old-price {
    text-decoration: line-through;
    display: block;
    color: #ccc;
    margin-bottom: 3px;
}
#product-images-large li {
    margin: 0 0 15px 0;
    padding: 0;
}
/*================================
    Cart and order history
==================================*/
.order-history th,
.cart-form th {
    white-space: nowrap;
    text-align: right;
}
.order-history th,
.cart-form tbody > tr > td {
    text-align: right;
    vertical-align: middle;
}
.order-history .left,
.cart-form .left {
    text-align: left
}
.order-history .right,
.cart-form .right {
    text-align: right
}
.order-history .center,
.cart-form .center,
.cart-form .quantity {
    text-align: center
}
.order-history td {
    padding-top: 10px !important;
}
.order-history-form {
    margin-top: -5px;
}
.cart-form .quantity input {
    width: 40px;
    text-align: center;
    margin: 0;
}
.cart-form label {
    margin-right: 10px;
    font-weight: bold;
}
#cart .discount-form .help-block {
    float: right;
}
.discount-form > .form-group,
.discount-form > .form-group > input,
.discount-form > .btn {
    display: inline-block;
}
.discount-form > .form-group > input {
    width: 180px;
}
.order-complete-form {
    margin-top: -10px;
}
.order-complete-form a {
    margin-right: 10px;
}
/*================================
            Wishlist
==================================*/
.wishlist img {
    vertical-align: middle;
}
.wishlist-actions {
    white-space: nowrap;
}
.wishlist form {
    margin: 0;
    float: right;
}
.wishlist .btn {
    margin-left: 5px
}
.wishlist .btn-primary {
    margin-left: 15px
}
/*================================
    Cart panel in checkout
==================================*/
.checkout-panel li {
    border-bottom: 1px dashed #bbb;
    color: #999;
}
.checkout-panel .price,
.order-totals,
.checkout-panel .btn {
    float: right;
    text-align: right;
    margin-top: 10px;
}
.order-totals span {
    display: inline-block;
    min-width: 60px;
}
/*================================
        Checkout forms
==================================*/
#checkout .left,
#checkout .right {
    display: none !important
}
#checkout .middle {
    width: 100%
}
.checkout-form legend {
    border: 0;
    margin: 0 0 0 -10px;
    padding: 10px;
    width: auto;
}
.checkout-form fieldset {
    border: 1px solid #ddd;
    border-radius: 4px;
    margin-bottom: 20px;
    padding: 5px 25px;
}
.checkout-form .input_id_same_billing_shipping label,
.checkout-form .input_id_remember label {
    width: auto !important;
    font-weight: normal;
    margin-right: 10px;
}
#complete .btn-primary {
    margin-right: 10px;
}
/*================================
    Inline card type selector
==================================*/
.checkout-form .form-group > ul {
    padding: 0;
    list-style-type: none;
}
.checkout-form .form-group li {
    display: inline;
    margin-right: 5px;
}
.checkout-form .form-group li > label {
    font-weight: normal;
    margin-bottom: 0;
}
#id_card_ccv {
    width: 70px !important;
    min-width: 70px;
}
/*================================
    Checkout expiry fields
==================================*/
.card-expiry-fields select {
    width: auto
}
.card-expiry-fields > label {
    display: block;
}
.card-expiry-fields .form-group {
    display: inline-block;
    margin-bottom: 0;
}
.card-expiry-fields .form-group > label {
    display: none
}
/*================================
            HELPERS
==================================*/
.errorlist,
.error-msg {
    padding-left: 0;
    list-style-type: none;
    color: #B94A48;
    font-weight: bold;
}
