{% load i18n shop_tags mezzanine_tags %}
{% spaceless %}
<a href="{% url "shop_cart" %}">
<span class="glyphicon glyphicon-shopping-cart"></span>
{% blocktrans count request.cart.total_quantity as cart_quantity %}1 item{% plural %}{{ cart_quantity }} items{% endblocktrans %}
{% trans "in cart" %}:
{{ request.cart.total_price|currency }}</a><br>
{% if request.cart.total_quantity != 0 %}
<a href="{% url "shop_checkout" %}" class="btn btn-primary">
    {% if request.session.order.step %}{% trans "Return to Checkout" %}{% else %}{% trans "Go to Checkout" %}{% endif %}
</a><br>
{% endif %}
{% if settings.SHOP_USE_WISHLIST %}
<a href="{% url "shop_wishlist" %}" class="btn-wishlist">
<span class="glyphicon glyphicon-star"></span>
{% blocktrans count request.wishlist|length as wishlist_count %}Wishlist contains 1 item{% plural %} Wishlist contains {{ wishlist_count }} items{% endblocktrans %}</a>
{% endif %}
{% endspaceless %}
