{% extends "admin/change_list.html" %}

{% block extrahead %}
{{ block.super }}
<style>
input[type=text] {width:70px !important; float:right;}
.vDateField, .vTimeField {float:none !important;}
</style>
{% endblock %}
